<template>
  <el-dialog
    top="4vh"
    :title="title"
    :visible.sync="visible"
    :before-close="handleClose"
    width="60%"
    :close-on-click-modal="false"
    v-if="visible"
  >
    <div class="dialog-header">
      <el-form ref="form" :model="searchForm" label-width="70px">
        <el-form-item label="名称">
          <el-input
            v-model="searchForm.project_name_"
            clearable
            :placeholder="$t('navigator.searchTip')"
          >
          </el-input>
        </el-form-item>
      </el-form>
      <el-divider direction="vertical" class="line"></el-divider>
      <div>
        <el-button
          icon="el-icon-search"
          type="primary"
          class="btn btn-plus"
          @click="handleSearch"
        >
          {{ $t('common.search') }}
        </el-button>
      </div>
    </div>
    <div style="min-height: 700px;">
      <el-table
        ref="table"
        tooltip-effect="dark"
        :data="tableData"
        :min-height="600"
        style="width: 100%"
        class="single-select-table"
        @selection-change="handleSelectionChange"
      >
        <el-table-column
          type="selection"
          width="55"
          align="center"
        ></el-table-column>
        <el-table-column
          prop="projectName"
          show-overflow-tooltip
          label="项目名称"
          align="center"
        >
        </el-table-column>
        <el-table-column
          prop="leader"
          show-overflow-tooltip
          label="牵头市领导"
          align="center"
        >
        </el-table-column>

        <el-table-column
          prop="closing"
          show-overflow-tooltip
          label="是否结项"
          align="center"
        >
          <template v-slot="{row}">
            {{ row.closing === '0' ? '已结项' : '未结项' }}
          </template>
        </el-table-column>
      </el-table>
    </div>
    <pagination
      :pageResult="pageResult"
      @size-change="handleSizeChange"
      @current-change="handleCurrentChange"
    />
    <span slot="footer" class="dialog-footer">
      <el-button type="primary" @click="submit">
        确认
      </el-button>
      <el-button @click="handleClose">
        {{ $t('common.cancel') }}
      </el-button>
    </span>
  </el-dialog>
</template>

<script>
import req from '@/request.js'
import pagination from '@/components/pagination'
const portal = window.context.portal
export default {
  name: 'projectDailog',
  components: {
    pagination
  },
  data() {
    return {
      title: '选择',
      visible: false,
      tableData: [],
      searchForm: {},
      pageResult: {
        page: 1,
        pageSize: 20,
        total: 0
      },
      params: {
        pageBean: {
          page: 1,
          pageSize: 20
        }
      }
    }
  },
  created() {
    this.getData(this.params)
  },
  methods: {
    open() {
      this.visible = true
    },
    handleClose() {
      this.visible = false
    },
    handleSelectionChange(rows) {
      // 单选
      if (rows.length > 1) {
        this.$refs.table.clearSelection()
        let obj = rows[1]
        this.$refs.table.toggleRowSelection(obj)
        rows = rows.slice(1)
      }
      this.multipleSelection = rows
    },
    handleSearch() {
      let obj = this.searchForm
      let querys = []
      for (let i in obj) {
        if (obj[i]) {
          querys.push({
            group: 'main',
            operation: 'LIKE',
            parentGroup: '',
            property: i,
            relation: 'AND',
            value: obj[i]
          })
        }
      }
      this.params.querys = querys
      this.getData(this.params)
    },
    getData(params) {
      req
        .post(
          portal + '/majorProjects/municipalMajorProjectManagement/v1/query',
          params
        )
        .then(res => {
          const data = (res && res.data) || {}
          this.tableData = data.rows || []
          this.pageResult = {
            page: data.page,
            pageSize: data.pageSize,
            total: data.total
          }
        })
    },
    handleSizeChange(pageSize) {
      this.params.pageBean = {...this.dialogParams.pageBean, pageSize}
      this.getData(this.params)
    },
    handleCurrentChange(page) {
      this.params.pageBean = {...this.dialogParams.pageBean, page}
      this.getData(this.params)
    },
    submit() {
      this.visible = false
      this.$emit('select', this.multipleSelection)
    }
  }
}
</script>

<style lang="scss" scoped>
.dialog-header {
  display: flex;
  align-items: center;
  margin-bottom: 10px;
  .line {
    margin: 0 30px;
  }
  .btn-plus {
    margin-right: 10px;
  }
  /deep/ .el-form-item--small.el-form-item {
    margin-bottom: 0;
  }
  /deep/ .el-form {
    height: 40px;
  }
}
/deep/ .single-select-table thead .el-table-column--selection .cell {
  display: none;
}
</style>
